@@ -1,3 +1,42 @@
+/*
+  ----------------------------------------------------------------
+	Speech Signal Processing Toolkit (SPTK): version 3.0
+			 SPTK Working Group
+
+		   Department of Computer Science
+		   Nagoya Institute of Technology
+				and
+    Interdisciplinary Graduate School of Science and Engineering
+		   Tokyo Institute of Technology
+		      Copyright (c) 1984-2000
+			All Rights Reserved.
+
+  Permission is hereby granted, free of charge, to use and
+  distribute this software and its documentation without
+  restriction, including without limitation the rights to use,
+  copy, modify, merge, publish, distribute, sublicense, and/or
+  sell copies of this work, and to permit persons to whom this
+  work is furnished to do so, subject to the following conditions:
+
+    1. The code must retain the above copyright notice, this list
+       of conditions and the following disclaimer.
+
+    2. Any modifications must be clearly marked as such.
+
+  NAGOYA INSTITUTE OF TECHNOLOGY, TOKYO INSITITUTE OF TECHNOLOGY,
+  SPTK WORKING GROUP, AND THE CONTRIBUTORS TO THIS WORK DISCLAIM
+  ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING ALL
+  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT
+  SHALL NAGOYA INSTITUTE OF TECHNOLOGY, TOKYO INSITITUTE OF
+  TECHNOLOGY, SPTK WORKING GROUP, NOR THE CONTRIBUTORS BE LIABLE
+  FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY
+  DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
+  WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS
+  ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
+  PERFORMANCE OF THIS SOFTWARE.
+ ----------------------------------------------------------------
+*/
+
 /************************************************************************
 *									*
 *    MLSA Digital Filter for Speech Synthesis				*
@@ -30,7 +69,7 @@
 *									*
 ************************************************************************/
 
-static char *rcs_id = "$Id: mlsadf.c,v 1.1.1.1 2000/03/01 13:58:28 yossie Exp $";
+static char *rcs_id = "$Id: mlsadf.c,v 1.3 2002/12/25 05:31:54 sako Exp $";
 
 
 /*  Standard C Libraries  */
@@ -55,6 +94,7 @@ double	mlsadf(), exp();
 #define	BFLAG		FA
 #define	PADEORDER	4
 #define NGAIN		FA
+#define INVERSE		FA
 
 
 /*  Command Name  */
@@ -76,6 +116,7 @@ void usage(int status)
     fprintf(stderr, "       -b    : output filter coefficient b  [%s]\n", BOOL[BFLAG]);
     fprintf(stderr, "       -P P  : order of pade approximation  [%d]\n", PADEORDER);
     fprintf(stderr, "       -k    : filtering without gain       [%s]\n", BOOL[NGAIN]);
+    fprintf(stderr, "       -v    : inverse filter               [%s]\n", BOOL[INVERSE]);
     fprintf(stderr, "       -h    : print this message\n");
     fprintf(stderr, "  infile:\n");
     fprintf(stderr, "       filter input (float)                 [stdin]\n");
@@ -95,7 +136,7 @@ void main(int argc, char **argv)
 		fprd = FPERIOD, iprd = IPERIOD, i, j;
     FILE	*fp = stdin, *fpc = NULL;
     double	*c, *inc, *cc, *d, x, a = ALPHA, atof();
-    Boolean	bflag = BFLAG, ngain = NGAIN;
+    Boolean	bflag = BFLAG, ngain = NGAIN, inverse = INVERSE;
     
     if ((cmnd = strrchr(argv[0], '/')) == NULL)
 	cmnd = argv[0];
@@ -124,6 +165,9 @@ void main(int argc, char **argv)
 		    pd = atoi(*++argv);
 		    --argc;
 		    break;
+		case 'v':
+		    inverse = 1 - inverse;
+		    break;
 		case 'b':
 		    bflag = 1 - bflag;
 		    break;
@@ -160,11 +204,19 @@ void main(int argc, char **argv)
     if(freadf(c, sizeof(*c), m+1, fpc) != m+1) exit(1);
     if(! bflag)
 	mc2b(c, c, m, a);
+    if(inverse){
+	c[0] = 0;
+	for(i=1; i<=m; i++) c[i] *= -1;
+    }
 	
     for(;;){
 	if(freadf(cc, sizeof(*cc), m+1, fpc) != m+1) exit(0);
 	if(! bflag)
 	    mc2b(cc, cc, m, a);
+        if(inverse){
+	    cc[0] = 0;
+	    for(i=1; i<=m; i++) cc[i] *= -1;
+        }
 	    
 	for(i=0; i<=m; i++)
 	    inc[i] = (cc[i] - c[i])* (double) iprd / (double) fprd;
